ConcurrentRuntime

Struct ConcurrentRuntime 

pub struct ConcurrentRuntime {
    channel_sender: Sender<GCArc<GCDatapointValue>>,
    concurrent_threads: u16,
    thread_ctx: ThreadCtx,
    threads: Vec<JoinHandle<()>>,
}
Concurrent runtime used to distribute messages to the subscribers using multiple threads.

Fields

channel_sender: Sender<GCArc<GCDatapointValue>>concurrent_threads: u16thread_ctx: ThreadCtxthreads: Vec<JoinHandle<()>>

Implementations



impl ConcurrentRuntime

pub fn new( datapoint_mapping: Arc<RwLock<DatapointMapping>>, concurrent_threads: u16, queue_size: usize, ) -> Self

pub fn get_mapping(&self) -> &RwLock<DatapointMapping>

Returns a reference to the asynchronous subscriber mapping.

pub fn get_sender_channel(&self) -> Sender<GCArc<GCDatapointValue>>

Returns a reference to the sender channel.

pub fn start(&mut self)

Starts the message broker and distributes the messages to the subscribers using multiple threads.